# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-10-04 16:23
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('autocert', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='certificate',
            name='domains_to_request',
            field=models.TextField(blank=True, help_text='Space separated list of domains to request in cert'),
        ),
        migrations.RemoveField(
            model_name='certificate',
            name='domain',
        ),
    ]
